$primary: {{ INDIGO_PRIMARY_COLOR }};
$primary-light: #F2F7F8;

// Theme fonts
$font-family-title: 'Inter', sans-serif;
$serif: Crimson;
$f-sans-serif: Crimson, 'Open Sans','Helvetica Neue', Helvetica, Arial, sans-serif;
@import url('https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600;700;800&display=swap');
// Initialize the Open edX Bootstrap theme
@import 'edx-bootstrap/sass/open-edx/theme';


// Introducing new variables

$dark: #111827;
$light-dark: #374151;
$big-screen: 1200px;



// Introducing dark-theme variables

$primary-d: #AEC7F6;
$primary-light-d: #292A2C;
$gray-light: #E5E7EB;
$gray-lighter: #c8c8c8;
$light-dark-d: #374151;
$text-color-d: #F8F8F8;
$text-color-primary: #DDDFE2;
$border-color-d: #777792;
$light-overlay-d: #36383B;
$danger-d: #FFA07A;
$success-d: #54CF5E;
$btn-color-d: #112F6B;
$body-bg-d: #0D0D0E;

$instructor-input-border-color: $gray-lighter;
$light-theme-switch-bg-color: #1D386A;
$dark-theme-switch-bg-color: #717D8A;

$warning-400: #ffe340;
$warning-700: #9c4607;
$warning-accent-700: #fffcf5;

$page-color-transition: transparent .2s ease, color .2s ease;
