## mako

<%page expression_filter="h"/>

<%namespace name='static' file='../static_content.html'/>
<%!
from openedx.core.djangolib.js_utils import (
    dump_js_escaped_json, js_escaped_string
)
%>
<!-- NEW IN INDIGO: update classes for layout -->
% if mobile_only:
<div class="program-list-wrapper container">
    <div class="program-list-container">
        <div class="program-cards-container"></div>
    </div>
    <div class="sidebar"></div>
</div>
% else:
<div class="program-list-wrapper container">
    <div class="program-list-container">
        <div class="js-program-list-header"></div>
        <div class="program-cards-container"></div>
    </div>
    <div class="sidebar"></div>
</div>
% endif

<%block name="js_extra">
<%static:webpack entry="ProgramListFactory">
ProgramListFactory({
    marketingUrl: '${marketing_url | n, js_escaped_string}',
    programsData: ${programs | n, dump_js_escaped_json},
    userProgress: ${progress | n, dump_js_escaped_json},
    userPreferences: ${user_preferences | n, dump_js_escaped_json},
    mobileOnly: ${mobile_only | n, dump_js_escaped_json}
});
</%static:webpack>
</%block>
