// Include custom xblocks
.wrap-instructor-info a.instructor-info-action {
    background: $primary !important;
    color: white !important;
}
.indigo-dark-theme { 
    select {
        background: transparent;
        color: $text-color-d;
    }
    .modal .inner-wrapper{
        background: $body-bg-d;
        color: $text-color-d;
    }
    .xblock--drag-and-drop {
        .keyboard-help-dialog {
            .modal-window {
                background: $primary-light-d;
            }
            .modal-content {
                background: $primary-light-d;
            }
            .modal-dismiss-button {
                color: $text-color-d;
            }
        }
    }
    .xmodule_display.xmodule_AboutBlock a:link, 
    .xmodule_display.xmodule_AboutBlock a:visited, 
    .xmodule_display.xmodule_AboutBlock a:hover, 
    .xmodule_display.xmodule_AboutBlock a:active, 
    .xmodule_display.xmodule_AboutBlock a:focus, 
    .xmodule_display.xmodule_CourseInfoBlock a:link, 
    .xmodule_display.xmodule_CourseInfoBlock a:visited, 
    .xmodule_display.xmodule_CourseInfoBlock a:hover, 
    .xmodule_display.xmodule_CourseInfoBlock a:active, 
    .xmodule_display.xmodule_CourseInfoBlock a:focus, 
    .xmodule_display.xmodule_HtmlBlock a:link, 
    .xmodule_display.xmodule_HtmlBlock a:visited, 
    .xmodule_display.xmodule_HtmlBlock a:hover, 
    .xmodule_display.xmodule_HtmlBlock a:active, 
    .xmodule_display.xmodule_HtmlBlock a:focus, 
    .xmodule_display.xmodule_StaticTabBlock a:link, 
    .xmodule_display.xmodule_StaticTabBlock a:visited, 
    .xmodule_display.xmodule_StaticTabBlock a:hover, 
    .xmodule_display.xmodule_StaticTabBlock a:active, 
    .xmodule_display.xmodule_StaticTabBlock a:focus {
        color: $primary-d;
    }
    .xmodule_display.xmodule_AboutBlock p, 
    .xmodule_display.xmodule_CourseInfoBlock p, 
    .xmodule_display.xmodule_HtmlBlock p, 
    .xmodule_display.xmodule_StaticTabBlock p {
        color: $text-color-d;
    }
    .xmodule_display.xmodule_AboutBlock ol, 
    .xmodule_display.xmodule_AboutBlock ul, 
    .xmodule_display.xmodule_CourseInfoBlock ol, 
    .xmodule_display.xmodule_CourseInfoBlock ul, 
    .xmodule_display.xmodule_HtmlBlock ol, 
    .xmodule_display.xmodule_HtmlBlock ul, 
    .xmodule_display.xmodule_StaticTabBlock ol, 
    .xmodule_display.xmodule_StaticTabBlock ul {
        color: $text-color-d;
    }
    .xmodule_display.xmodule_AboutBlock pre, 
    .xmodule_display.xmodule_CourseInfoBlock pre, 
    .xmodule_display.xmodule_HtmlBlock pre, 
    .xmodule_display.xmodule_StaticTabBlock pre {
        color: $text-color-d;
    }
    .hd-1, .hd-2, .hd-3, .hd-4, .hd-5, .hd-6, .hd-7, .hd-8 {
        color: $text-color-d;
    }
    .xmodule_display.xmodule_AboutBlock img, 
    .xmodule_display.xmodule_CourseInfoBlock img, 
    .xmodule_display.xmodule_HtmlBlock img, 
    .xmodule_display.xmodule_StaticTabBlock img {
        background-color: $text-color-d
    }
    .wrap-instructor-info a.instructor-info-action {
        background: $primary-d !important;
        color: $btn-color-d !important;
    }
    .xmodule_display.xmodule_ProblemBlock div.problem-progress {
        color: $text-color-d;
    }
    .content-wrapper #main .xblock .btn-link {
        color: $primary-d;
        &:hover, &:focus {
            color: $primary-d !important;
        }
    }
    .xblock--drag-and-drop .problem-progress {
        color: $text-color-d;
    }
    .xblock--drag-and-drop .title1 {
        color: $text-color-d;
    }
    .xblock--drag-and-drop .drag-container {
        background: $primary-light-d;
    }
    .xblock--drag-and-drop .drag-container .option {
        background: $primary-d;
        color: $btn-color-d;
    }
    .xblock--drag-and-drop .btn-default:hover, 
    .xblock--drag-and-drop .btn-default.is-hovered, 
    .xblock--drag-and-drop .btn-default:focus, 
    .xblock--drag-and-drop .btn-default.is-focused {
        border: 1px solid $primary-d;
        color: $primary-d;
    }
    .xmodule_display.xmodule_VideoBlock .video {
        background-color: $primary-light-d;
    }
    .wrapper--xblock .problem__header {
        color: $text-color-d;
    }
    .wrapper--xblock .message .message__content {
        color: $text-color-d;
    }
    .wrapper--openassessment .wrapper--staff-area .wrapper--staff-toolbar .ui-staff__button,
    .openassessment .ui-slidable__container .ui-slidable:not([disabled]) {
        color: $text-color-d;
        &:hover {
            color: $primary-d;
            background: $primary-light-d !important;
        }
        &:focus{
            color: $primary-d;
        }
    }
    .openassessment .openassessment__steps__step.is--in-progress .step__status__value {
        background: $primary-d;
    }
    .openassessment .is--in-progress.openassessment__steps__step {
        border-color: $primary-d;
    }
    h1, h2, h3, h4, h5, h6 {
        color: $text-color-d;
    }
    .openassessment .openassessment__steps .openassessment__steps__step .step__header .step__title {
        .step__counter:before, .step__label {
        color: $text-color-d;
        }
    }
    .openassessment .openassessment__steps__step .step__instruction,
    .openassessment .submission__answer__part__prompt__copy {
        color: $text-color-d;
    }
    .openassessment .list--actions .action--submit, .openassessment .openassessment_student_info_form .action--submit-username {
        border-color: $primary-d !important;
        background: $primary-d !important;
        color: $btn-color-d !important;
    }
    .openassessment .openassessment__steps__step.is--unavailable .step__counter:before, 
    .openassessment .openassessment__steps__step.is--unavailable .step__label, 
    .openassessment .openassessment__steps__step.is--unavailable .step__deadline {
        color:$text-color-d;
    }
    .wrapper--xblock input[type=text], .wrapper--xblock input[type=email], .wrapper--xblock input[type=password], .wrapper--xblock textarea {
        background: none !important;
        border-color: $primary-d;
        color: $text-color-d;
    }
    .openassessment .step--self-assessment .self-assessment__assessment .response__submission__label, .openassessment .step--peer-assessment .peer-assessment__assessment .response__submission__label, .openassessment .step--response .response__submission__actions .response__submission__label, .openassessment .step--response .response__submission__content .response__submission__label {
        color: $text-color-d;
    }

    .openassessment .step--student-training .student-training__assessment .question__answers,
    .openassessment .step--self-assessment .self-assessment__assessment .question__answers {
        .wrapper--input .answer__label, .answer__tip, .answer__points, .answer__points__label {
            color: $text-color-d;
        }
    }

    .openassessment .openassessment__steps__step {
        background: none;
    }
    .openassessment .step--response .response__submission {
        background: $primary-light-d;
    }
    .openassessment .submission__answer__part__prompt {
        background: none;
        border-color: $primary-d;
    }
    .openassessment .submission__answer__part__text__value {
        color: $text-color-d;
    }
    .openassessment .submission__answer__part__text__value:not(textarea){
        background: none;
    }

    .xmodule_display.xmodule_ProblemBlock div.problem .question-description {
        color: $text-color-primary;
    }
    label, .openassessment .step--grade .grade__value__description {
        color: $text-color-d;
    }
    .xmodule_display.xmodule_ProblemBlock div.problem .choicegroup input:focus+label, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:focus+label, .xmodule_display.xmodule_ProblemBlock div.problem .choicegroup input:hover+label, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:hover+label {
        border-color: $primary-d;
    }
    .xmodule_display.xmodule_ProblemBlock div.problem .choicegroup input+label.choicegroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input+label.choicegroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input+label.choicetextgroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input+label.choicetextgroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input+section.choicetextgroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input+section.choicetextgroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicegroup input:focus+label.choicegroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:focus+label.choicegroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input:focus+label.choicetextgroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:focus+label.choicetextgroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input:focus+section.choicetextgroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:focus+section.choicetextgroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicegroup input:hover+label.choicegroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:hover+label.choicegroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input:hover+label.choicetextgroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:hover+label.choicetextgroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input:hover+section.choicetextgroup_incorrect, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:hover+section.choicetextgroup_incorrect,
    .xmodule_display.xmodule_ProblemBlock div.problem .notification.error {
        border-color: $danger-d;
    }
    .xmodule_display.xmodule_ProblemBlock div.problem .indicator-container .status.incorrect .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .notification.error .icon {
        color: $danger-d;
    }
    .xmodule_display.xmodule_ProblemBlock .problem .capa_inputtype.textline > .incorrect input, .xmodule_display.xmodule_ProblemBlock .problem .inputtype.formulaequationinput > .incorrect input {
        border-color: $danger-d;
    }
    .xmodule_display.xmodule_ProblemBlock .problem .capa_inputtype.textline > .incorrect .status .status-icon:after, 
    .xmodule_display.xmodule_ProblemBlock .problem .inputtype.formulaequationinput > .incorrect .status .status-icon:after {
        color: $danger-d;
    }
    .xmodule_display.xmodule_ProblemBlock div.problem .choicegroup input+label.choicegroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input+label.choicegroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input+label.choicetextgroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input+label.choicetextgroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input+section.choicetextgroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input+section.choicetextgroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicegroup input:focus+label.choicegroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:focus+label.choicegroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input:focus+label.choicetextgroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:focus+label.choicetextgroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input:focus+section.choicetextgroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:focus+section.choicetextgroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicegroup input:hover+label.choicegroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:hover+label.choicegroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input:hover+label.choicetextgroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:hover+label.choicetextgroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input:hover+section.choicetextgroup_correct, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:hover+section.choicetextgroup_correct {
        border-color: $success-d;
    }
    .xmodule_display.xmodule_ProblemBlock div.problem .choicegroup input+label.choicegroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input+label.choicegroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input+label.choicetextgroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input+label.choicetextgroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input+section.choicetextgroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input+section.choicetextgroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicegroup input:focus+label.choicegroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:focus+label.choicegroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input:focus+label.choicetextgroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:focus+label.choicetextgroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input:focus+section.choicetextgroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:focus+section.choicetextgroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicegroup input:hover+label.choicegroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:hover+label.choicegroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input:hover+label.choicetextgroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:hover+label.choicetextgroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup .choicegroup input:hover+section.choicetextgroup_correct .status-icon::after, .xmodule_display.xmodule_ProblemBlock div.problem .choicetextgroup input:hover+section.choicetextgroup_correct .status-icon::after {
        color: $success-d;
    }
    .xmodule_display.xmodule_ProblemBlock div.problem .notification.general, .xmodule_display.xmodule_ProblemBlock div.problem .notification.general .icon {
        border-color: $primary-d;
    }
    .xmodule_display.xmodule_ProblemBlock div.problem .action .submit-attempt-container .submit {
        background: $primary-d;
        border-color: $primary-d;
        color: $btn-color-d;
    }
    .xmodule_display.xmodule_ProblemBlock div.problem .action .problem-action-btn:hover, 
    .xmodule_display.xmodule_ProblemBlock div.problem .action .problem-action-btn:focus, 
    .xmodule_display.xmodule_ProblemBlock div.problem .action .problem-action-btn:active,
    .xmodule_display.xmodule_ProblemBlock div.problem .notification.general .icon {
        color: $primary-d;
    }
    .xmodule_display.xmodule_ProblemBlock .problem .capa_inputtype.textline>.unanswered input, .xmodule_display.xmodule_ProblemBlock .problem .capa_inputtype.textline>.unsubmitted input, .xmodule_display.xmodule_ProblemBlock .problem .inputtype.formulaequationinput>.unanswered input, .xmodule_display.xmodule_ProblemBlock .problem .inputtype.formulaequationinput>.unsubmitted input {
        color: $text-color-d;
        background: none;
    }
    .xmodule_display.xmodule_ProblemBlock div.problem div div.equation span.MathJax_CHTML, .xmodule_display.xmodule_ProblemBlock div.problem div div.equation span.MathJax, .xmodule_display.xmodule_ProblemBlock div.problem div div.equation span.MathJax_SVG {
        background: $primary-light-d;
    }
    .step--student-training .student-training__assessment 
    .assessment__rubric__question--feedback textarea, 
    .step--student-training .student-training__display__response, 
    .openassessment .submission__feedback__fields textarea, .openassessment 
    .step--self-assessment .self-assessment__assessment .assessment__rubric__question--feedback textarea, 
    .openassessment .step--self-assessment .self-assessment__display__response, 
    .openassessment .step--peer-assessment .peer-assessment__assessment .assessment__rubric__question--feedback textarea, 
    .openassessment .step--peer-assessment .peer-assessment__display__response, 
    .openassessment .step--response .response__submission__content .submission__file__description textarea, 
    .openassessment .step--response .response__submission__content .submission__answer__part__text textarea, 
    .openassessment .staff-assessment__assessment .assessment__rubric__question--feedback textarea, .openassessment 
    .staff-assessment__display__response, .step--response .step__rubric .question__answers .answer--feedback .answer__value, 
    .step--student-training .student-training__assessment .question__answers .answer--feedback .answer__value, .openassessment .step--self-assessment .self-assessment__assessment .question__answers .answer--feedback .answer__value, 
    .openassessment .step--peer-assessment .peer-assessment__assessment .question__answers .answer--feedback .answer__value, .openassessment .staff-assessment__assessment .question__answers .answer--feedback .answer__value {
        overflow-y: auto;
    }
    .xmodule_display.xmodule_ProblemBlock div.problem .notification.warning {
        border-color: $danger-d;
    }
    .xmodule_display.xmodule_ProblemBlock div.problem .notification.warning .icon {
        color: $danger-d;
    }
    .xmodule_display.xmodule_ProblemBlock div.problem .notification.problem-hint {
        background: $primary-light-d;
        border-color: $primary-light-d;
        .icon {
            color: $text-color-d;
        }
        .notification-message {
            ol {
                li {
                    color: $text-color-d;
                    strong {
                        color: $text-color-d;
                    }
                }
            }
        }
        .notification-btn-wrapper {
            button {
                border-color: $primary-d !important;
                background: none !important;
                color: $primary-d;
            }
        }
    }

    .ui-dialog.ui-widget.ui-widget-content, 
    .ui-dialog-titlebar.ui-widget-header,
    .ui-dialog-buttonpane.ui-widget-content,
    .dialog-confirm.ui-dialog-content.ui-widget-content{
        background: $body-bg-d;
        color: $text-color-d;
        & .ui-button.ui-state-default:active, 
        & .ui-button.ui-state-default:focus
        {box-shadow: none;}
    }

    .openassessment .submission__answer__part__prompt__copy a, 
    .wrapper--xblock .message .message__content a{
        color: $primary-d;
        &:hover{
            color: #77a0ee;
        }
    }

    .openassessment {
        .submission__peer-evaluations__title,
        .self-assessment__display__title,.step--self-assessment .self-assessment__display__title,
        .peer-assessment__display__title,.step--self-assessment .peer-assessment__display__title,,
        .staff-assessment__display__title, .step--self-assessment .staff-assessment__display__title,{
            color: $text-color-d !important; // open-assessment scss file used !important 
        }
    }

    div.wrapper--xblock {
        
        .openassessment__student-training--instructions.step__message > .message__content{
            color: $primary-light-d;
        }
        .openassessment .openassessment__steps__step .step__message.message--waiting{
            background: $primary-light-d;
        }
        .message--complete, 
        .step--student-training .message--correct, 
        .step--student-training .message--correct{
            background: #ecfaec;
            & .message__content{
                color: $primary-light-d;
                a {
                    color: $btn-color-d;
                }
            }
        }

        .message--incomplete, 
        .step--student-training .message--incorrect, 
        .step--student-training .wrapper--xblock .message--incorrect{
            background: #fff9eb;
            & .message__content{
                color: $primary-light-d;
                a {
                    color: $btn-color-d;
                }
            }
        }

        .openassessment .openassessment__steps__step.is--in-progress .step__status__value .copy{
            color: $primary-light-d;
        }  

        .openassessment .openassessment__steps .openassessment__steps__step .step__header .step__deadline{
            color: $border-color-d;
        }

        .step--response .step__rubric{
            background: $primary-light-d;
        }

        .step--response .step__rubric .question__answers .wrapper--input .answer__label,
        .step--student-training .student-training__assessment .question__answers .wrapper--input .answer__label, 
        .openassessment .step--self-assessment .self-assessment__assessment .question__answers .wrapper--input .answer__label, 
        .openassessment .step--peer-assessment .peer-assessment__assessment .question__answers .wrapper--input .answer__label, 
        .openassessment .staff-assessment__assessment .question__answers .wrapper--input .answer__label{
            color: $text-color-d;
        }

        .step--response .step__rubric .question__answers .answer__tip, 
        .step--student-training .student-training__assessment .question__answers .answer__tip, 
        .openassessment .step--self-assessment .self-assessment__assessment .question__answers .answer__tip, 
        .openassessment .step--peer-assessment .peer-assessment__assessment .question__answers .answer__tip, 
        .openassessment .staff-assessment__assessment .question__answers .answer__tip,
        .step--response .step__rubric .question__answers .answer__points, 
        .step--student-training .student-training__assessment .question__answers .answer__points, 
        .openassessment .step--self-assessment .self-assessment__assessment .question__answers .answer__points, 
        .openassessment .step--peer-assessment .peer-assessment__assessment .question__answers .answer__points, 
        .openassessment .staff-assessment__assessment .question__answers .answer__points
        .step--response .step__rubric .question__answers .answer__points__label, 
        .step--student-training .student-training__assessment .question__answers .answer__points__label, 
        .openassessment .step--self-assessment .self-assessment__assessment .question__answers .answer__points__label, 
        .openassessment .step--peer-assessment .peer-assessment__assessment .question__answers .answer__points__label, 
        .openassessment .staff-assessment__assessment .question__answers .answer__points__label
        {
            color: $text-color-primary;
        }

        .tox .tox-toolbar, .tox .tox-toolbar__overflow, 
        .tox .tox-toolbar__primary{
            background-color: $body-bg-d;
            color: $text-color-d;
        }

        .tox .tox-tbtn{
            color: $text-color-d;
        }

        .tox .tox-tbtn__select-chevron svg{
            fill: $text-color-d;
        }

        .tox .tox-edit-area__iframe{
          background-color: $gray-light;
        }

        .openassessment .submission__answer__display__title{
            color: $text-color-primary;
        }

        .openassessment .question__score{
            .question__score__value,
            .label,
            .question__score__potential
            { color: $text-color-d; }
        } 
        .openassessment .answer{
            .answer__source__value-with-points,
            .answer__value__value,
            .answer__source,
            .answer__points__label,
            .answer__points
            { color: $text-color-d; }
        }
        .openassessment .question__score__value:after{
            color: $text-color-d;
        }


        // for staff 
        .ui-staff{
            .wrapper--content{
                background: $body-bg-d;
                color: $text-color-d;
            }

            .step__message.message.message--warning,
            .step__message.message.message--correct,
            .message--incorrect,
            .message--complete,
            .message--incomplete{
                color: $primary-light-d;
                & .message__content{ 
                    color: $primary-light-d;
                    a {
                        color: $btn-color-d;
                    }
                }
            }
        }

        .openassessment .ui-staff__content__section{
            .wrapper--input{
                background: $body-bg-d;
                color: $text-color-d;
            }
        }

        .openassessment .staff-info__workflow-cancellation .staff-info__cancel-submission__content .comments__label{
            color: $text-color-d;
        }

    }

    #feedback-container{
        background: $body-bg-d;
        border: 1px solid $text-color-d;
        p{
            color: $text-color-d;
        }
    }

    .emoji-button{
        background-color: $body-bg-d;
        border: 1px solid $light-overlay-d;

        &:hover,
        &:hover:not(:disabled){
            background-color: $light-dark-d;
        }
    }
      
    .emoji-button-highlighted{
        background-color: $text-color-d;
      
        &:hover,
        &:hover:not(:disabled){
            background-color: $text-color-d;
        }
    }
    .xblock.xmodule_display.xmodule_HtmlBlock .blue-text{color: $primary;}
    .xblock.xmodule_display.xmodule_HtmlBlock ul li::marker,
    .xblock.xmodule_display.xmodule_HtmlBlock ul li strong{
        color: $text-color-d;
    }
    .xblock.xmodule_display.xmodule_HtmlBlock .course-structure h3{
        color: $text-color-d;
    }


    .edx-notes-wrapper{
        .annotator-hl{
            background: orange;
            color: $primary-light-d;
        }

        .annotator-outer.annotator-viewer{
            div:first-of-type{
                color: $text-color-d;
            }

            .annotator-annotation.annotator-item{
                background: $body-bg-d;

                .annotator-note{
                    color: $text-color-d !important;
                }

                .annotator-tags{
                    border-color: $primary-light-d;
                    .annotator-tag{
                        background: lightgrey;
                        color: $primary-light-d;
                        
                    }
                } 
            }

            .annotator-controls {
                .annotator-close::before,
                .annotator-edit::before,
                .annotator-delete::before{
                    color: $primary-d;
                }
            }
        }

        .annotator-adder{
            button{
                background: $primary-light-d !important;
                &::after{ 
                    color: $primary-d;
                    text-shadow: none;
                }
                &::before{ background: $primary-light-d;}
            }
        }

        .annotator-outer.annotator-editor{
            .annotator-widget{
                background: $body-bg-d !important;
            }
            .annotator-listing{
                background: $body-bg-d;
                .annotator-item{
                    border-top: 1px solid grey;
                    &:first-child textarea{
                        background: $light-overlay-d !important;
                        color: $text-color-d !important;
                    }
                    input{
                        background: $light-overlay-d;
                        color: $text-color-d;
                    }
                }
            }
            .annotator-controls{
                background: $primary-light-d !important;
                box-shadow: none;
                .annotator-save{
                    background: $primary-d;
                    color: $primary-light-d;
                    &:hover{
                        color: $primary-light-d;
                    }
                }
                .annotator-cancel{
                    color: $primary-d;
                }
            }
        }  
    }
}
