// Include custom Footer
.wrapper-footer {
    padding: 25px 0;
    border-top: 1px solid $gray-light;
    @include media-breakpoint-up(md) {
        padding: 45px 0;
    }
}
footer.tutor-container {
    margin: 0 auto;
    padding: 0 15px;
    max-width: 1600px;
    text-align: center;
    box-sizing: border-box;
    @include media-breakpoint-up(lg) {
        text-align: left;
    }
    .footer-top {
        margin: 0 0 15px;
        &:after {
            clear: both;
            display: block;
            content: "";
        }
        .powered-area {
            margin: 0 0 10px;
            @include media-breakpoint-up(md) {
                margin: 0 0 15px;
            }
            @include media-breakpoint-up(lg) {
                float: left;
            }
        }
    }
    .logo-list {
        list-style: none;
        margin: 0;
        padding: 0;
        letter-spacing: -.3em;
        li {
            display: inline-block;
            vertical-align: middle;
            padding: 0 5px;
            letter-spacing: normal;
            position: relative;
            font-size: 12px;
            line-height: 18px;
            color: #515661;
            &:first-child {
                padding-left: 0;
            }
            &:last-child {
                padding-left: 20px;
                &:after {
                    position: absolute;
                    left: 5px;
                    top: 50%;
                    content: "";
                    width: 1px;
                    height: 29px;
                    margin: -14px 0 0;
                    background: #515661;;
                }
            }
        }
    }
    .nav-colophon {
        display: block;
        overflow: hidden;
        ol {
            text-align: center;
            li {
                display: inline-block;
                vertical-align: top;
                padding: 0 8px;
                font-size: 14px;
                line-height: 20px;
                @include media-breakpoint-up(md) {
                    padding: 0 12px;
                    font-size: 16px;
                    line-height: 24px;
                }
                a {
                    color: $light-dark;
                    text-decoration: none;
                    &:hover {
                        color: $dark;
                        text-decoration: none;
                    }
                }
            }
        }
    }
    .copyright-site {
        display: block;
        font-size: 12px;
        line-height: 16px;
        color: $light-dark;
    }
}

body.indigo-dark-theme {
    .wrapper-footer {
        border-top: 1px solid $border-color-d;
        background: $body-bg-d;
    }
    footer.tutor-container {
        .logo-list {
            li {
                color: $text-color-primary;
                &:last-child {
                    &:after {
                        background: $text-color-primary;
                    }
                }
            }
        }
        .nav-colophon {
            ol {
                li {
                    a {
                        color:$text-color-primary;
                        &:hover {
                            color: $text-color-d;
                        }
                    }
                }
            }
        }
        .copyright-site {
            color: $text-color-primary;
        }

    }
}
